Struct ZwpTabletManagerV2
pub struct ZwpTabletManagerV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
controller object for graphic tablet devices
An object that provides access to the graphics tablets available on this system. All tablets are associated with a seat, to get access to the actual tablets, use zwp_tablet_manager_v2.get_tablet_seat.
This interface has no events.
Implementations
impl ZwpTabletManagerV2
impl ZwpTabletManagerV2
pub fn get_tablet_seat<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpTabletSeatV2
pub fn get_tablet_seat<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ZwpTabletSeatV2
get the tablet seat
Get the zwp_tablet_seat_v2 object for the given seat. This object provides access to all graphics tablets in this seat.
pub fn destroy(&self)
pub fn destroy(&self)
release the memory for the tablet manager object
Destroy the zwp_tablet_manager_v2 object. Objects created from this object are unaffected and should be destroyed separately.